@@ -156,16 +156,16 @@ available_in_status_codes_db <- function( )
 ##' @param signatures a data.frame with the supported signatures.
 ##' @param solver a character string giving the solver name.
 ##' @param method a function registered as solver method.
+##' @param plugin a character string giving the plgug-in name.
 ##' @return TRUE on success
 ##' @family plugin functions
 ##' @rdname ROI_plugin_register_solver_method
 ##' @export
-ROI_plugin_register_solver_method <- function( signatures, solver, method ){
+ROI_plugin_register_solver_method <- function( signatures, solver, method , plugin = solver ) {
     solver_signature_db$set(solver, signatures)
-    for( i in 1:nrow(signatures) )
+    for ( i in seq_len(nrow(signatures)) )
         do.call(solver_db$set_entry, c(as.list(signatures[i,]),
-                                             list(solver = solver),
-                                             list(FUN = method)))
+                                       list(solver = solver, plugin = plugin, FUN = method)))
 
     invisible( TRUE )
 }
